==> nextcloud-app-tasks-0.16.1-1.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/ja.js <==
OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "今後のタスク",
    "Important" : "重要",
    "Today" : "今日",
    "Week" : "週",
    "All" : "すべて",
    "Current" : "現在",
    "Completed" : "完了",
    "Tasks" : "タスク",
    "The Tasks app for Nextcloud" : "Nextcloud用のタスクアプリ",
    "Default list" : "デフォルトリスト",
    "Visibility of Smart Collections" : "スマートコレクションの表示",
    "Hidden" : "隠す",
    "Visible" : "表示する",
    "Automatic" : "自動",
    "Share with users or groups" : "ユーザーまたはグループと共有する",
    "No users or groups" : "ユーザーまたはグループはありません",
    "Can edit" : "編集可能",
    "Unshare with {displayName}" : "{displayName}との共有を解除",
    "Unable to delete the share." : "共有を解除できません。",
    "Unable to change permissions." : "権限を変更できません。",
    "Edit" : "編集",
    "Copy private link" : "プライベートリンクをコピー",
    "Copied" : "コピーしました",
    "Cannot copy" : "コピーできません",
    "Export" : "エクスポート",
    "Delete" : "削除",
    "Unshare" : "共有を解除",
    "List name" : "リスト名",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "カレンダー\"{calendar}\"とカレンダーに対応するすべてのイベントとタスクが削除されます。",
    "This will unshare the calendar \"{calendar}\"." : "カレンダー \"{calendar}\" の共有を解除します。",
    "Calendar link copied to clipboard." : "カレンダーリンクをクリップボードにコピー",
    "Calendar link could not be copied to clipboard." : "カレンダーリンクをクリップボードにコピーできませんでした。",
    "The name \"{calendar}\" is already used." : "\"{calendar}\"の名称は既に使用されています。",
    "An empty name is not allowed." : "件名を入力してください。",
    "An error occurred, unable to delete the calendar." : "エラーが発生したため、カレンダーを削除できません。",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["{num}個のエンティティと共有"],
    "Trash bin" : "ごみ箱",
    "Name" : "名前",
    "Deleted" : "削除済み",
    "Restore" : "復元",
    "Delete permanently" : "完全に削除する",
    "Empty trash bin" : "ゴミ箱を空にする",
    "Untitled task" : "タイトルなしタスク",
    "Untitled event" : "無題のイベント",
    "Untitled item" : "無題の項目",
    "Unknown calendar" : "不明なカレンダー",
    "Could not load deleted calendars and objects" : "削除されたカレンダーとオブジェクトを読み込めませんでした。",
    "Could not restore calendar or event" : "カレンダーまたはイベントを復元できませんでした。",
    "Do you really want to empty the trash bin?" : "本当にゴミ箱を空にしますか？",
    "Select a calendar" : "カレンダーを選択",
    "Click here to add a note." : "クリックしてノートを追加",
    "Cancel" : "キャンセル",
    "Close" : "閉じる",
    "Delete all completed tasks." : "全ての完了したタスクを削除",
    "Delete completed tasks." : "完了したタスクを削除",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "カレンダー \"{calendar}\" から完了したタスクをすべて削除しました。",
    "No errors" : "エラーはありません",
    "Open your browser console for more details" : "詳細はブラウザーコンソールを開きます",
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["{failedCount} 個のタスクが削除できませんでした"],
    "Select tags to filter by" : "フィルターするタグを選択してください",
    "Add an important task to \"{calendar}\"…" : "\"{calendar}\"に重要なタスクを追加する",
    "Add a task due today to \"{calendar}\"…" : "\"{calendar}\"に今日が期限のタスクを追加する",
    "Add a current task to \"{calendar}\"…" : "\"{calendar}\"に現在のタスクを追加する",
    "Add a task to \"{calendar}\"…" : "\"{calendar}\"にタスクを追加する",
    "Change sort order" : "並び順を変更",
    "Relevance" : "関連性",
    "Sort by completed state, due date, priority, start date and summary." : "完了状態、期日、優先順位、開始日、および要約で並べ替えます。",
    "Start date" : "開始日",
    "Due date" : "期限",
    "Created date" : "データーを作成",
    "Last modified" : "最終更新日",
    "Completed date" : "完了日",
    "Priority" : "優先度",
    "Sort by priority and summary." : "優先順位と要約で並べ替えます。",
    "Alphabetically" : "アルファベット順",
    "Sort by summary and priority." : "要約と優先順位で並べ替えます。",
    "Manually" : "手動",
    "Sort by manual order." : "手動で並べ替えます。",
    "Task is pinned" : "タスクはピンされています",
    "Task has a note" : "タスクにはノートがあります",
    "{complete} % completed" : "{complete} %完了",
    "Add subtask" : "サブタスクを追加",
    "Show subtasks" : "サブタスクを表示",
    "Hide subtasks" : "サブタスクを非表示",
    "Delete task" : "タスクを削除",
    "[Yesterday]" : "[昨日]",
    "[Today]" : "[今日]",
    "[Tomorrow]" : "[明日]",
    "Add a subtask to \"{task}\"…" : "\"{task}\"にサブタスクを追加...",
    "Task is completed" : "タスク完了",
    "Create a new task" : "新しいタスクを作成する",
    "Create task" : "タスクを作成する",
    "Open task" : "タスクを開く",
    "_%n Completed Task_::_%n Completed Tasks_" : ["完了済みタスク %n"],
    "Tomorrow" : "明日",
    "Add List…" : "リストを追加…",
    "All day" : "終日",
    "Unpin" : "ピンの解除",
    "Pin" : "ピン",
    "Show in Calendar" : "カレンダーに表示する",
    "Details" : "詳細",
    "Select a classification" : "分類を選択",
    "Select a status" : "ステータスを選択",
    "Select tags" : "タグを選択",
    "Notes" : "ノート",
    "Reminders" : "リマインダー",
    "Repeat" : "繰り返し",
    "When shared show full event" : "共有時にすべてのイベントを表示",
    "When shared show only busy" : "共有時に実行中のみを表示",
    "When shared hide this event" : "共有時にこのイベントを隠す",
    "Needs action" : "アクションが必要",
    "In process" : "進行中",
    "Canceled" : "キャンセルされた",
    "Loading task from server." : "タスクをサーバーから読み込み中。",
    "Task not found!" : "タスクがありません！",
    "Set start date" : "開始日を設定",
    "Set due date" : "期限を設定",
    "Priority {priority}: low" : "優先度{priority}:低",
    "Priority {priority}: medium" : "優先度{priority}:中",
    "Priority {priority}: high" : "優先度{priority}:高",
    "No priority assigned" : "優先順位が割り当てられていません",
    "{percent} % completed" : "{percent} %完了",
    "upcoming tasks" : "今後のタスク",
    "No tasks today" : "今日はタスクなし",
    "Mark as done" : "完了としてマーク",
    "No due date assigned" : "期限はありません",
    "[Due today]" : "[今日まで]",
    "[Due tomorrow]" : "[明日まで]",
    "[Due] L" : "L [まで]",
    "Successfully created the task." : "タスクの作成に成功しました",
    "Could not delete the task." : "タスクを削除できませんでした",
    "Synchronizing to the server." : "サーバーと同期中",
    "Task successfully saved to server." : "タスクはサーバーに正常に保存されました。",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "サーバー上でタスクが変更されたため、タスクを更新できませんでした。 クリックして更新してください。ローカルの変更は破棄されます。",
    "Could not update the task." : "タスクを更新できませんでした",
    "Successfully updated the task." : "タスクのアップデートに成功しました",
    "An error occurred" : "エラーが発生しました",
    "Create a task" : "タスクを作成する",
    "Message from {author} in {conversationName}" : "{conversationName} で {author} からのメッセージ",
    "[Due on] LL" : "LL [まで]",
    "[Was due yesterday]" : "[昨日が期限]",
    "[Starts today]" : "[今日開始]",
    "[Starts tomorrow]" : "[明日開始]",
    "[Started yesterday]" : "[昨日から]"
},
"nplurals=1; plural=0;");

==> nextcloud-app-tasks-0.17.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/ja.js <==
OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "今後のタスク",
    "Important" : "重要",
    "Today" : "今日",
    "Week" : "週",
    "All" : "すべて",
    "Current" : "現在",
    "Completed" : "完了",
    "Tasks" : "タスク",
    "The Tasks app for Nextcloud" : "Nextcloud用のタスクアプリ",
    "Hidden" : "隠す",
    "Visible" : "表示する",
    "Automatic" : "自動",
    "Default list" : "デフォルトリスト",
    "Visibility of Smart Collections" : "スマートコレクションの表示",
    "Share with users or groups" : "ユーザーまたはグループと共有する",
    "No users or groups" : "ユーザーまたはグループはありません",
    "Unable to delete the share." : "共有を解除できません。",
    "Unable to change permissions." : "権限を変更できません。",
    "Can edit" : "編集可能",
    "Unshare with {displayName}" : "{displayName}との共有を解除",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "カレンダー\"{calendar}\"とカレンダーに対応するすべてのイベントとタスクが削除されます。",
    "This will unshare the calendar \"{calendar}\"." : "カレンダー \"{calendar}\" の共有を解除します。",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["{num}個のエンティティと共有"],
    "Calendar link copied to clipboard." : "カレンダーリンクをクリップボードにコピー",
    "Calendar link could not be copied to clipboard." : "カレンダーリンクをクリップボードにコピーできませんでした。",
    "The name \"{calendar}\" is already used." : "\"{calendar}\"の名称は既に使用されています。",
    "An empty name is not allowed." : "件名を入力してください。",
    "An error occurred, unable to delete the calendar." : "エラーが発生したため、カレンダーを削除できません。",
    "Edit" : "編集",
    "Copy private link" : "プライベートリンクをコピー",
    "Copied" : "コピーしました",
    "Cannot copy" : "コピーできません",
    "Export" : "エクスポート",
    "Delete" : "削除",
    "Unshare" : "共有を解除",
    "List name" : "リスト名",
    "Untitled task" : "タイトルなしタスク",
    "Untitled event" : "無題のイベント",
    "Untitled item" : "無題の項目",
    "Unknown calendar" : "不明なカレンダー",
    "Could not load deleted calendars and objects" : "削除されたカレンダーとオブジェクトを読み込めませんでした。",
    "Could not restore calendar or event" : "カレンダーまたはイベントを復元できませんでした。",
    "Do you really want to empty the trash bin?" : "本当にゴミ箱を空にしますか？",
    "Empty trash bin" : "ゴミ箱を空にする",
    "Trash bin" : "ごみ箱",
    "Name" : "名前",
    "Deleted" : "削除済み",
    "Restore" : "復元",
    "Delete permanently" : "完全に削除する",
    "Cancel" : "キャンセル",
    "Notification" : "通知",
    "Email" : "メール",
    "Audio notification" : "音声通知",
    "Other notification" : "その他の通知",
    "Edit time" : "時刻を変更",
    "Remove reminder" : "リマインダーを削除",
    "Add reminder" : "リマインダーを追加",
    "Go back" : "戻る",
    "before at" : "次の時間分早めに通知",
    "_second_::_seconds_" : ["秒"],
    "_minute_::_minutes_" : ["分"],
    "_hour_::_hours_" : ["時間"],
    "_day_::_days_" : ["日"],
    "_week_::_weeks_" : ["週"],
    "Select a calendar" : "カレンダーを選択",
    "Click here to add a note." : "クリックしてノートを追加",
    "Create new tasks" : "新しいタスクを作成する",
    "Create tasks" : "タスクを作成する",
    "Creating new tasks…" : "新しいタスクを作成する",
    "Close" : "閉じる",
    "Delete all completed tasks." : "全ての完了したタスクを削除",
    "Delete completed tasks." : "完了したタスクを削除",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "カレンダー \"{calendar}\" から完了したタスクをすべて削除しました。",
    "No errors" : "エラーはありません",
    "Open your browser console for more details" : "詳細はブラウザーコンソールを開きます",
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["{failedCount} 個のタスクが削除できませんでした"],
    "Select tags to filter by" : "フィルターするタグを選択してください",
    "Add an important task to \"{calendar}\"…" : "\"{calendar}\"に重要なタスクを追加する",
    "Add a task due today to \"{calendar}\"…" : "\"{calendar}\"に今日が期限のタスクを追加する",
    "Add a current task to \"{calendar}\"…" : "\"{calendar}\"に現在のタスクを追加する",
    "Add a task to \"{calendar}\"…" : "\"{calendar}\"にタスクを追加する",
    "Relevance" : "関連性",
    "Sort by completed state, due date, priority, start date and summary." : "完了状態、期日、優先順位、開始日、および要約で並べ替えます。",
    "Start date" : "開始日",
    "Due date" : "期限",
    "Created date" : "データーを作成",
    "Last modified" : "最終更新日",
    "Completed date" : "完了日",
    "Priority" : "優先度",
    "Sort by priority and summary." : "優先順位と要約で並べ替えます。",
    "Alphabetically" : "アルファベット順",
    "Sort by summary and priority." : "要約と優先順位で並べ替えます。",
    "Tags" : "タグ",
    "Manually" : "手動",
    "Sort by manual order." : "手動で並べ替えます。",
    "Change sort order" : "並び順を変更",
    "[Yesterday]" : "[昨日]",
    "[Today]" : "[今日]",
    "[Tomorrow]" : "[明日]",
    "Add a subtask to \"{task}\"…" : "\"{task}\"にサブタスクを追加...",
    "Task is pinned" : "タスクはピンされています",
    "Task has a note" : "タスクにはノートがあります",
    "{complete} % completed" : "{complete} %完了",
    "Add subtask" : "サブタスクを追加",
    "Show subtasks" : "サブタスクを表示",
    "Hide subtasks" : "サブタスクを非表示",
    "Delete task" : "タスクを削除",
    "Task is completed" : "タスク完了",
    "Create a new task" : "新しいタスクを作成する",
    "Create task" : "タスクを作成する",
    "Open task" : "タスクを開く",
    "_%n Completed Task_::_%n Completed Tasks_" : ["完了済みタスク %n"],
    "Tomorrow" : "明日",
    "Add List…" : "リストを追加…",
    "When shared show full event" : "共有時にすべてのイベントを表示",
    "When shared show only busy" : "共有時に実行中のみを表示",
    "When shared hide this event" : "共有時にこのイベントを隠す",
    "Needs action" : "アクションが必要",
    "In process" : "進行中",
    "Canceled" : "キャンセルされた",
    "Loading task from server." : "タスクをサーバーから読み込み中。",
    "Task not found!" : "タスクがありません！",
    "Set start date" : "開始日を設定",
    "Set due date" : "期限を設定",
    "Priority {priority}: low" : "優先度{priority}:低",
    "Priority {priority}: medium" : "優先度{priority}:中",
    "Priority {priority}: high" : "優先度{priority}:高",
    "No priority assigned" : "優先順位が割り当てられていません",
    "{percent} % completed" : "{percent} %完了",
    "All day" : "終日",
    "Unpin" : "ピンの解除",
    "Pin" : "ピン",
    "Show in Calendar" : "カレンダーに表示する",
    "Details" : "詳細",
    "Select a classification" : "分類を選択",
    "Select a status" : "ステータスを選択",
    "Select tags" : "タグを選択",
    "Notes" : "ノート",
    "Mark as done" : "完了としてマーク",
    "No due date assigned" : "期限はありません",
    "[Due today]" : "[今日まで]",
    "[Due tomorrow]" : "[明日まで]",
    "[Due] L" : "L [まで]",
    "upcoming tasks" : "今後のタスク",
    "No tasks today" : "今日はタスクなし",
    "Successfully created the task." : "タスクの作成に成功しました",
    "Could not delete the task." : "タスクを削除できませんでした",
    "Synchronizing to the server." : "サーバーと同期中",
    "Task successfully saved to server." : "タスクはサーバーに正常に保存されました。",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "サーバー上でタスクが変更されたため、タスクを更新できませんでした。 クリックして更新してください。ローカルの変更は破棄されます。",
    "Could not update the task." : "タスクを更新できませんでした",
    "Successfully updated the task." : "タスクのアップデートに成功しました",
    "An error occurred" : "エラーが発生しました",
    "Create a task" : "タスクを作成する",
    "Message from {author} in {conversationName}" : "{conversationName} で {author} からのメッセージ",
    "[Due on] LL" : "LL [まで]",
    "[Was due yesterday]" : "[昨日が期限]",
    "[Starts today]" : "[今日開始]",
    "[Starts tomorrow]" : "[明日開始]",
    "[Started yesterday]" : "[昨日から]"
},
"nplurals=1; plural=0;");
